@@ -22,6 +22,7 @@ import django_filters
 
 from django.contrib.auth.models import User, Group
 
+
 def findips(start, end):
     start = ip_address(start)
     end = ip_address(end)
@@ -36,12 +37,14 @@ Model AceConfig where is registered system configuration
 
 """
 
-
 class AceConfig(SingletonModel):
     org = models.TextField(u'Nome da organização/empresa.', max_length=2000, default='Empresa Exemplo', blank=True, null=True)
-    email_from = models.EmailField(u'Email de senhas: Endereço de remetente.', max_length=75,
+    email_to = models.EmailField(u'Endereço de destinatário.', max_length=75,
                                    default='no-reply@empresa.com',
-                                   help_text="Campo De do email. Ex: <em>fulano@empresa.com</em>.")
+                                   help_text="Notificações de alteração de ramais/senhas:  - Ex: <em>fulano@empresa.com</em>.")
+    email_from = models.EmailField(u'Endereço de remetente.', max_length=75,
+                                   default='no-reply@empresa.com',
+                                   help_text="Email de senhas e notificações de alteração de ramais/senhas - Ex: <em>fulano@empresa.com</em>.")
     email_co = models.EmailField(u'Email - Cópia: Endereço de destino.', max_length=75, default='no-reply@empresa.com',
                                  help_text="Campo do email para envio de cópia de mensagem. Ex: <em>fulano@empresa.com</em>.")
     password_email_text = models.TextField(u'Mensagem adicional (Texto puro).', max_length=6000,
@@ -83,11 +86,24 @@ class Log(models.Model):
     event_date = models.DateTimeField(u'Data de modificação',editable=False,blank=True,null=True)
     record_type = models.CharField(max_length=50,editable=False,blank=True,null=True)
     actor = models.CharField(max_length=200,editable=False,)
+    object_id = models.CharField(max_length=30,editable=False,null=True)
 
     def __unicode__(self):
         return self.record_name
 
 
+class Person(User):
+
+    class Meta:
+        proxy = True
+        ordering = ('first_name', )
+
+    def __unicode__(self):
+        return u'%s %s' % (self.first_name, self.last_name)
+
+
+
+
 
 class Manufactorer(models.Model):
     class Meta:
@@ -959,7 +975,7 @@ class Phone(models.Model):
         )
 
     num = models.CharField('Número', max_length=14, unique=True, help_text='Número do ramal ou código da senha')
-    user = models.ForeignKey(User, blank=True, null=True, verbose_name=u'Usuário')
+    user = models.ForeignKey(Person, blank=True, null=True, verbose_name=u'Usuário')
     place = models.ForeignKey(Place, verbose_name=u'Local', blank=True, null=True)
     active = models.BooleanField(default=False, verbose_name='Ativo', help_text='Indica se número está em uso ou não')
     password = models.BooleanField(default=False, verbose_name='É senha',
@@ -1042,9 +1058,9 @@ class Phoneownership(models.Model):
         verbose_name = 'Posse de telefone'
         verbose_name_plural = 'Posses de telefone'
 
-    active = models.BooleanField(editable=False, default=True)
+    active = models.BooleanField(editable=False, default=True, verbose_name="Ativo(a)")
     phone = models.ForeignKey(Phone, blank=True, null=True, verbose_name='Telefone')
-    user = models.ForeignKey(User, blank=True, null=True, verbose_name=u'Usuário')
+    user = models.ForeignKey(Person, blank=True, null=True, verbose_name=u'Usuário')
     date_activation = models.DateTimeField(u'Data de ativação', blank=True, null=True, editable=False,
                                            auto_now_add=True)
     date_deactivation = models.DateTimeField(u'Data de desativação', blank=True, null=True, editable=False)
